@@ -103,6 +103,6 @@ rLG <- function(n, mu = 0.5)
           n <- ceiling(n)
           p <- runif(n)
           r <- qLG(p, mu=mu)
-          r
+          as.integer(r)
   }
 #----------------------------------------------------------------------------------------
