@@ -159,6 +159,6 @@ rZIBB <- function(n, mu = 0.5, sigma = 0.5, nu = 0.1, bd = 1)
           n <- ceiling(n)
           p <- runif(n)
           r <- qZIBB(p, mu = mu, sigma = sigma, nu = nu, bd = bd)
-          r
+          as.integer(r)
   }
 #-----------------------------------------------------------------------------------------
