@@ -161,6 +161,6 @@ rZINBI <- function(n, mu = 1, sigma = 1, nu = 0.3)
   n <- ceiling(n)
   p <- runif(n)
   r <- qZINBI(p, mu=mu, sigma=sigma, nu=nu)
-  r
+  as.integer(r)
 }
 #------------------------------------------------------------------------------------------
