@@ -128,6 +128,6 @@ rZIP2 <- function(n, mu=5, sigma=0.1)
           n <- ceiling(n)
           p <- runif(n)
           r <- qZIP2(p, mu = mu, sigma = sigma)
-          r
+          as.integer(r)
   }
 #-----------------------------------------------------------------------------------------
